<?php

namespace FiloBlu\EsbRma\Model\Loader;

use FiloBlu\Esb\Api\Data\ObjectTypeDescriptorInterface;
use FiloBlu\Esb\Api\Data\ObjectTypeInterface;
use FiloBlu\Esb\Api\ObjectTypeLoaderInterface;
use FiloBlu\Esb\Framework\ObjectType\Endpoint\AbstractEndpoint;
use Magento\Rma\Api\RmaRepositoryInterface;
use RuntimeException;

/**
 * Class RmaLoader
 * @package FiloBlu\EsbRma\Model\Loader
 */
class RmaLoader extends AbstractEndpoint implements ObjectTypeLoaderInterface
{
    /**
     * @var \Magento\Rma\Api\RmaRepositoryInterface
     */
    protected $rmaRepository;

    /**
     * RmaLoader constructor.
     * @param \Magento\Rma\Api\RmaRepositoryInterface $rmaRepository
     * @param \FiloBlu\Esb\Api\Data\ObjectTypeDescriptorInterface $objectTypeDescriptor
     */
    public function __construct(
        RmaRepositoryInterface $rmaRepository,
        ObjectTypeDescriptorInterface $objectTypeDescriptor
    ) {
        parent::__construct($objectTypeDescriptor);
        $this->rmaRepository = $rmaRepository;
    }

    /**
     * @inheritDoc
     */
    public function get(ObjectTypeInterface $objectType)
    {
        if (!$this->isSuitableFor($objectType)) {
            throw new RuntimeException("Incompatible loader for type {$objectType->getTypeCode()}");
        }

        return $this->rmaRepository->get($objectType->getId());
    }

    /**
     * @inheritDoc
     */
    public function getName(): string
    {
        return 'Esb rma loader';
    }

    /**
     * @inheritDoc
     */
    public function getUniqueName(): string
    {
        return 'FiloBlu_Esb::rma_loader';
    }
}
